==> haskell-wai-websockets-3.0.1.2-186-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-websockets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-websockets
version:              3.0.1.2
visibility:           public
id:                   wai-websockets-3.0.1.2-4Cce6mEIVvV5CABa9uOUzK
key:                  wai-websockets-3.0.1.2-4Cce6mEIVvV5CABa9uOUzK
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Jasper Van der Jeugt, Ting-Yen Lai
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Provide a bridge between WAI and the websockets package.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-websockets>.

category:             Web, Yesod
abi:                  124596388b1a8bda3338723ee21b04eb
exposed:              True
exposed-modules:      Network.Wai.Handler.WebSockets
import-dirs:          /usr/lib/ghc-8.10.2/site-local/wai-websockets-3.0.1.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/wai-websockets-3.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/wai-websockets-3.0.1.2
hs-libraries:         HSwai-websockets-3.0.1.2-4Cce6mEIVvV5CABa9uOUzK
depends:
    base-4.14.1.0 bytestring-0.10.10.0
    case-insensitive-1.2.1.0-67UnwAOqbT8BnKxqPm1bDl
    http-types-0.12.3-9d6q1lRkXJ82WkEPNqln4g
    network-3.1.2.0-5sobkliwwmD9npzHIw7lyx transformers-0.5.6.2
    wai-3.2.2.1-6oI1VVe1KBYB1dop6PmYGX
    websockets-0.12.7.1-7T13R40MIdBJK0baa6WRmx

haddock-interfaces:
    /usr/share/doc/haskell-wai-websockets/html/wai-websockets.haddock

haddock-html:         /usr/share/doc/haskell-wai-websockets/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-websockets-3.0.1.2-192-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-websockets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-websockets
version:              3.0.1.2
visibility:           public
id:                   wai-websockets-3.0.1.2-CsDJgNV6a8oGaefQipLcCu
key:                  wai-websockets-3.0.1.2-CsDJgNV6a8oGaefQipLcCu
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Jasper Van der Jeugt, Ting-Yen Lai
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Provide a bridge between WAI and the websockets package.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-websockets>.

category:             Web, Yesod
abi:                  3b9d3d043427378821d228ebeea89ac8
exposed:              True
exposed-modules:      Network.Wai.Handler.WebSockets
import-dirs:          /usr/lib/ghc-8.10.2/site-local/wai-websockets-3.0.1.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/wai-websockets-3.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/wai-websockets-3.0.1.2
hs-libraries:         HSwai-websockets-3.0.1.2-CsDJgNV6a8oGaefQipLcCu
depends:
    base-4.14.1.0 bytestring-0.10.10.0
    case-insensitive-1.2.1.0-5DMNWHGVnoo4dOW265EsdJ
    http-types-0.12.3-4dn2vNwjKqBLyMKxAY4nqS
    network-3.1.2.1-DR7SoDNxNxPGBCy1viiSIs transformers-0.5.6.2
    wai-3.2.2.1-FATjpie2VuDHM19Pi1wCI7
    websockets-0.12.7.2-GdQU6XHYCsgHOVq20q9cpf

haddock-interfaces:
    /usr/share/doc/haskell-wai-websockets/html/wai-websockets.haddock

haddock-html:         /usr/share/doc/haskell-wai-websockets/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
